@@ -9,7 +9,7 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')
 
 
 from architext import *
-
+from typing import Optional, Union, Callable
 # ==============================================================================
 # 单元测试部分
 # ==============================================================================
@@ -1480,6 +1480,435 @@ Files: {Files(visible=True, name="files")}
             class NotAProvider: pass
             message_with_text.has(NotAProvider)
 
+    async def test_zab_lstrip_and_rstrip(self):
+        """测试 lstrip, rstrip, 和 strip 方法是否能正确移除两侧的特定类型的 provider"""
+        # 1. 定义一个用于测试的子类
+        class SpecialTexts(Texts):
+            pass
+        url = "data:image/png;base64,FAKE_IMG"
+
+        # 2. 创建一个复杂的测试消息
+        message = UserMessage(
+            Texts("leading1"),
+            Texts("leading2"),
+            Images(url, name="image1"),
+            Texts("middle"),
+            SpecialTexts("special_middle"),
+            Images(url, name="image2"),
+            Texts("trailing1"),
+            SpecialTexts("special_trailing"), # rstrip(Texts) should stop here
+            Texts("trailing2")
+        )
+
+        # 3. 测试 rstrip(Texts)
+        r_stripped_message = UserMessage(*message.provider()) # 创建副本
+        r_stripped_message.rstrip(Texts)
+        # 应移除 "trailing2"，但在 "special_trailing" 处停止
+        self.assertEqual(len(r_stripped_message), 8)
+        self.assertIs(type(r_stripped_message[-1]), SpecialTexts)
+
+        # 4. 测试 lstrip(Texts)
+        l_stripped_message = UserMessage(*message.provider()) # 创建副本
+        l_stripped_message.lstrip(Texts)
+        # 应移除 "leading1" 和 "leading2"，但在 "image1" 处停止
+        self.assertEqual(len(l_stripped_message), 7)
+        self.assertIs(type(l_stripped_message[0]), Images)
+
+        # 5. 测试 strip(Texts)
+        stripped_message = UserMessage(*message.provider()) # 创建副本
+        stripped_message.strip(Texts)
+        # 应同时移除 "leading1", "leading2", 和 "trailing2"
+        self.assertEqual(len(stripped_message), 6)
+        self.assertIs(type(stripped_message[0]), Images)
+        self.assertIs(type(stripped_message[-1]), SpecialTexts)
+
+        # 6. 测试在一个只包含一种类型的消息上进行剥离
+        only_texts = UserMessage(Texts("a"), Texts("b"))
+        only_texts.strip(Texts)
+        self.assertEqual(len(only_texts), 0)
+
+        # 7. 测试剥离一个不包含目标类型的消息
+        only_images = UserMessage(Images("url1"), Images("url2"))
+        only_images.strip(Texts)
+        self.assertEqual(len(only_images), 2) # 不应改变
+
+        # 8. 测试在一个空消息上进行剥离
+        empty_message = UserMessage()
+        empty_message.strip(Texts)
+        self.assertEqual(len(empty_message), 0)
+
+        # 9. 测试剥离子类
+        message_ending_with_special = UserMessage(Texts("a"), SpecialTexts("b"))
+        message_ending_with_special.rstrip(SpecialTexts)
+        self.assertEqual(len(message_ending_with_special), 1)
+        self.assertIsInstance(message_ending_with_special[0], Texts)
+
+    async def test_zac_texts_join_parameter(self):
+        """测试 Texts provider 是否支持通过参数控制拼接方式"""
+        # 1. 测试默认行为：直接拼接
+        message_default = UserMessage(
+            Texts("First line."),
+            Texts("Second line.")
+        )
+        rendered_default = await message_default.render_latest()
+        self.assertEqual(rendered_default['content'], "First line.Second line.")
+
+        # 2. 测试新功能：使用 \n\n 拼接
+        # 假设新参数为 `newline=True`
+        message_newline = UserMessage(
+            Texts("First paragraph."),
+            Texts("Second paragraph.", newline=True)
+        )
+        rendered_newline = await message_newline.render_latest()
+        self.assertEqual(rendered_newline['content'], "First paragraph.\n\nSecond paragraph.")
+
+        # 3. 测试多个 provider 的情况
+        message_multiple = UserMessage(
+            Texts("First."),
+            Texts("Second.", newline=True),
+            Texts("Third.", newline=True)
+        )
+        rendered_multiple = await message_multiple.render_latest()
+        self.assertEqual(rendered_multiple['content'], "First.\n\nSecond.\n\nThird.")
+
+        # 4. 测试只有一个 provider 的情况
+        message_single = UserMessage(
+            Texts("Only one.", newline=True)
+        )
+        rendered_single = await message_single.render_latest()
+        self.assertEqual(rendered_single['content'], "Only one.")
+
+    async def test_zad_simple_render_without_refresh(self):
+        """测试 Messages(UserMessage('hi')).render() 是否能直接同步渲染"""
+        # This test checks if a simple message can be rendered synchronously
+        # without an explicit `await refresh()` or `await render_latest()`.
+        # Calling the synchronous render method directly on a new instance
+        rendered = Messages(UserMessage("hi", Images(url="data:image/png;base64,FAKE"))).render()
+
+        # The current implementation will likely fail here, returning []
+        self.assertEqual(len(rendered), 1)
+        self.assertEqual(rendered[0]['role'], 'user')
+
+        # Now we expect a list for multimodal content
+        content = rendered[0]['content']
+        self.assertIsInstance(content, list)
+        self.assertEqual(len(content), 2)
+        self.assertEqual(content[0]['type'], 'text')
+        self.assertEqual(content[0]['text'], 'hi')
+        self.assertEqual(content[1]['type'], 'image_url')
+        self.assertEqual(content[1]['image_url']['url'], "data:image/png;base64,FAKE")
+
+    async def test_zae_messages_representation(self):
+        """测试 Messages 对象的 __repr__ 方法是否提供可读的输出"""
+        messages = Messages(
+            UserMessage("Hello"),
+            AssistantMessage("Hi there!")
+        )
+
+        actual_repr = repr(messages)
+
+        # 一个可读的字符串形式应该像 Messages([...]) 这样，并包含其内部 message 的 repr
+        self.assertTrue(actual_repr.startswith("Messages(["), f"期望输出以 'Messages([' 开头，但得到 '{actual_repr}'")
+        self.assertTrue(actual_repr.endswith("])"), f"期望输出以 '])' 结尾，但得到 '{actual_repr}'")
+        self.assertIn("Message(role='user', items=", actual_repr)
+        self.assertIn("Message(role='assistant', items=", actual_repr)
+
+    async def test_zaf_message_absorption(self):
+        """测试Message对象是否能吸收嵌套的Message对象作为其内容"""
+        # 1. ToolResults吸收UserMessage
+        tool_results_1 = ToolResults(tool_call_id="call_1", content=UserMessage("hi"))
+        rendered_1 = await tool_results_1.render_latest()
+        self.assertEqual(rendered_1['content'], "hi")
+        self.assertEqual(rendered_1['tool_call_id'], "call_1")
+
+        # 2. UserMessage吸收AssistantMessage
+        user_message_1 = UserMessage("prefix", AssistantMessage("absorbed content"))
+        rendered_user_1 = await user_message_1.render_latest()
+        self.assertEqual(rendered_user_1['content'], "prefixabsorbed content")
+        self.assertEqual(len(user_message_1.provider()), 2) # Should be flattened
+
+        # 3. 复杂嵌套
+        final_message = ToolResults(tool_call_id="call_final", content=UserMessage("A", AssistantMessage("B", UserMessage("C"))))
+        rendered_final = await final_message.render_latest()
+        self.assertEqual(rendered_final['content'], "ABC")
+
+        # 4. 组合情况: ToolResults(UserMessage(Texts("a"), Texts("b"))) -> content="ab"
+        tool_results_2 = ToolResults(tool_call_id="call_2", content=UserMessage(Texts("a"), Texts("b")))
+        rendered_2 = await tool_results_2.render_latest()
+        self.assertEqual(rendered_2['content'], "ab")
+
+        # 5. 包含多模态内容的情况 (ToolResults应该只提取文本)
+        tool_results_3 = ToolResults(tool_call_id="call_3", content=UserMessage("text part", Images(url="some_url")))
+        rendered_3 = await tool_results_3.render_latest()
+        self.assertEqual(rendered_3['content'], "text part") # Images should be ignored
+
+        # 6. 直接传入字符串的情况应保持不变
+        tool_results_4 = ToolResults(tool_call_id="call_4", content="just a string")
+        rendered_4 = await tool_results_4.render_latest()
+        self.assertEqual(rendered_4['content'], "just a string")
+
+        # 7. 传入一个空的 Message
+        tool_results_5 = ToolResults(tool_call_id="call_5", content=UserMessage())
+        rendered_5 = await tool_results_5.render_latest()
+        self.assertEqual(rendered_5['content'], "")
+
+    async def test_zzb_final_message_render_logic(self):
+        """
+        最终版测试:
+        - render() 首次调用保证获取完整结果。
+        - 后续 render() 调用返回缓存结果，不会自动刷新。
+        - refresh() 显式刷新内容。
+        - render_latest() 总是获取最新内容。
+        """
+        from datetime import datetime
+        import time
+
+        # 1. 创建带有动态 provider 的 Message
+        timestamp_provider = Texts(lambda: str(datetime.now().timestamp()))
+        message = UserMessage("Time: ", timestamp_provider)
+
+        # 2. 第一次调用 render() - 应该刷新并返回完整内容
+        rendered_1 = await message.render()
+        content1 = rendered_1['content']
+        timestamp1_str = content1.replace("Time: ", "")
+        self.assertTrue(timestamp1_str, "render() 第一次调用应返回完整动态内容")
+
+        # 3. 第二次调用 render() - 不应自动刷新，返回缓存的内容
+        time.sleep(1)
+        rendered_2 = await message.render()
+        content2 = rendered_2['content']
+        self.assertEqual(content1, content2, "第二次调用 render() 应返回缓存内容，不应刷新")
+
+        # 4. 调用 refresh() - 显式刷新
+        time.sleep(1)
+        await message.refresh()
+
+        # 5. refresh() 后调用 render() - 应该返回刚刚刷新的新内容
+        rendered_3 = await message.render()
+        content3 = rendered_3['content']
+        timestamp3_str = content3.replace("Time: ", "")
+        self.assertNotEqual(content2, content3, "refresh() 后 render() 应返回新内容")
+
+        # 6. 调用 render_latest() - 总是获取最新内容
+        time.sleep(1)
+        rendered_latest = await message.render_latest()
+        content_latest = rendered_latest['content']
+        timestamp_latest_str = content_latest.replace("Time: ", "")
+        self.assertNotEqual(content3, content_latest, "render_latest() 应总是获取最新内容")
+
+        # 7. 测试 ToolResults
+        tool_results_msg = ToolResults(tool_call_id="call_123", content="Result from tool")
+        # ToolResults's content is static, so render() should always return the same full content
+        rendered_tool_1 = await tool_results_msg.render()
+        self.assertEqual(rendered_tool_1, {
+            "role": "tool",
+            "tool_call_id": "call_123",
+            "content": "Result from tool"
+        })
+        # Subsequent calls should also work
+        rendered_tool_2 = await tool_results_msg.render()
+        self.assertEqual(rendered_tool_1, rendered_tool_2)
+
+    async def test_zag_iadd_on_provider(self):
+        """测试对 provider 使用 += 操作符来追加文本"""
+        class Goal(Texts):
+            def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: str = "goal"):
+                super().__init__(text=text, name=name)
+
+            async def render(self) -> Optional[str]:
+                content = await super().render()
+                if content is None:
+                    return None
+                return f"<goal>{content}</goal>"
+
+        messages = Messages(UserMessage(Goal("hi")))
+
+        # This is the new syntax we want to test
+        goal_provider = messages.provider("goal")
+        goal_provider += "test"
+
+        rendered = await messages.render_latest()
+
+        self.assertEqual(len(rendered), 1)
+        self.assertEqual(rendered[0]['content'], "<goal>hitest</goal>")
+
+    async def test_zz_user_message_auto_merging(self):
+        """测试连续的UserMessage是否能自动合并"""
+        # 场景1: 初始化时合并
+        messages_init = Messages(UserMessage("hi"), UserMessage("hi2"))
+        self.assertEqual(len(messages_init), 1, "初始化时，两个连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_init[0]), 2, "合并后的UserMessage应该包含两个Texts provider")
+
+        rendered_init = await messages_init.render_latest()
+        self.assertEqual(rendered_init[0]['content'], "hihi2", "合并后渲染的内容不正确")
+
+        # 场景2: 追加时合并
+        messages_append = Messages(UserMessage("hi"))
+        messages_append.append(UserMessage("hi2"))
+        self.assertEqual(len(messages_append), 1, "追加时，两个连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_append[0]), 2, "追加合并后的UserMessage应该包含两个Texts provider")
+
+        rendered_append = await messages_append.render_latest()
+        self.assertEqual(rendered_append[0]['content'], "hihi2", "追加合并后渲染的内容不正确")
+
+        # 场景3: 追加RoleMessage时合并
+        messages_append.append(RoleMessage("user", "hi3"))
+        self.assertEqual(len(messages_append), 1, "追加RoleMessage时，连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_append[0]), 3, "追加RoleMessage合并后的UserMessage应该包含三个Texts provider")
+
+        rendered_append_role = await messages_append.render_latest()
+        self.assertEqual(rendered_append_role[0]['content'], "hihi2hi3", "追加RoleMessage合并后渲染的内容不正确")
+
+        # 场景4: 追加包含ContextProvider和字符串组合的RoleMessage时合并
+        class Goal(Texts):
+            def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: str = "goal", visible: bool = True, newline: bool = False):
+                super().__init__(text=text, name=name, visible=visible, newline=newline)
+
+            async def render(self) -> Optional[str]:
+                content = await super().render()
+                if content is None:
+                    return None
+                return f"<goal>{content}</goal>"
+
+        messages_append.append(RoleMessage("user", Goal("goal") + "hi4"))
+        self.assertEqual(len(messages_append), 1, "追加(ContextProvider + str)的RoleMessage时，未能正确合并")
+        self.assertEqual(len(messages_append[0]), 4, "追加(ContextProvider + str)的RoleMessage合并后的provider数量不正确")
+
+        rendered_append_combo = await messages_append.render_latest()
+        self.assertEqual(rendered_append_combo[0]['content'], "hihi2hi3<goal>goalhi4</goal>", "追加(ContextProvider + str)合并后渲染的内容不正确")
+
+        # 场景5: 被空消息隔开的同角色消息在渲染时合并
+        messages_separated = Messages(UserMessage("hi"), AssistantMessage(""), UserMessage("hi2"))
+        rendered_separated = await messages_separated.render_latest()
+        self.assertEqual(len(rendered_separated), 1, "被空消息隔开的同角色消息在渲染时应该合并")
+        self.assertEqual(rendered_separated[0]['content'], "hihi2", "被空消息隔开的同角色消息合并后内容不正确")
+
+    async def test_zzc_files_update_with_head(self):
+        """测试 Files.update 是否支持 head 参数以及新的 refresh 逻辑"""
+        test_file = "test_file_head.txt"
+        file_content = "Line 1\nLine 2\nLine 3\nLine 4\nLine 5"
+        with open(test_file, "w", encoding='utf-8') as f:
+            f.write(file_content)
+
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+
+            # 1. Test update with head=3 using the provider from Messages
+            files_provider = messages.provider("files")
+            self.assertIsInstance(files_provider, Files)
+            files_provider.update(path=test_file, head=3)
+
+            rendered_head = await messages.render_latest()
+            expected_head_content = "Line 1\nLine 2\nLine 3"
+            self.assertIn(f"<file_content>{expected_head_content}</file_content>", rendered_head[0]['content'])
+            self.assertNotIn("Line 4", rendered_head[0]['content'])
+
+            # 2. Test update without head (default behavior)
+            files_provider.update(path=test_file)
+            rendered_full = await messages.render_latest()
+            self.assertIn(f"<file_content>{file_content}</file_content>", rendered_full[0]['content'])
+
+            # 3. Test that refresh overwrites manual content when file exists
+            files_provider.update(path=test_file, content="manual content")
+            rendered_overwritten = await messages.render_latest()
+            self.assertIn(f"<file_content>{file_content}</file_content>", rendered_overwritten[0]['content'])
+            self.assertNotIn("manual content", rendered_overwritten[0]['content'])
+
+            # 4. Test that manual content is kept if file does not exist
+            non_existent_file = "non_existent_for_sure.txt"
+            files_provider.update(path=non_existent_file, content="manual content to keep")
+            rendered_kept = await messages.render_latest()
+            self.assertIn("<file_content>manual content to keep</file_content>", rendered_kept[0]['content'])
+
+        finally:
+            if os.path.exists(test_file):
+                os.remove(test_file)
+
+    async def test_zzd_files_update_with_string_head(self):
+        """测试 Files.update 是否能自动将字符串 head 参数转换为整数"""
+        test_file = "test_file_string_head.txt"
+        file_content = "Line 1\nLine 2\nLine 3\nLine 4\nLine 5"
+        with open(test_file, "w", encoding='utf-8') as f:
+            f.write(file_content)
+
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+
+            # Test update with head="3"
+            files_provider = messages.provider("files")
+            self.assertIsInstance(files_provider, Files)
+            # This is the part that will likely fail before implementation
+            files_provider.update(path=test_file, head="3")
+
+            rendered_head = await messages.render_latest()
+            expected_head_content = "Line 1\nLine 2\nLine 3"
+            self.assertIn(f"<file_content>{expected_head_content}</file_content>", rendered_head[0]['content'])
+            self.assertNotIn("Line 4", rendered_head[0]['content'])
+
+        finally:
+            if os.path.exists(test_file):
+                os.remove(test_file)
+
+    async def test_zzc_files_update_with_head_and_content(self):
+        """测试update同时设置path, content, head时的行为"""
+        existing_file = "test_file_existing.txt"
+        non_existent_file = "test_file_non_existent.txt"
+        existing_content = "Line 1 (from file)\nLine 2 (from file)\nLine 3 (from file)\nLine 4 (from file)"
+        manual_content = "Line 1 (manual)\nLine 2 (manual)\nLine 3 (manual)\nLine 4 (manual)"
+
+        # --- 场景1: 文件存在 ---
+        with open(existing_file, "w", encoding='utf-8') as f:
+            f.write(existing_content)
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+            files_provider = messages.provider("files")
+            files_provider.update(path=existing_file, content=manual_content, head=2)
+            rendered_existing = await messages.render_latest()
+            expected_existing_head = "Line 1 (from file)\nLine 2 (from file)"
+            self.assertIn(f"<file_content>{expected_existing_head}</file_content>", rendered_existing[0]['content'])
+            self.assertNotIn("manual", rendered_existing[0]['content'])
+        finally:
+            if os.path.exists(existing_file):
+                os.remove(existing_file)
+
+        # --- 场景2: 文件不存在 ---
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+            files_provider = messages.provider("files")
+            files_provider.update(path=non_existent_file, content=manual_content, head=2)
+            rendered_non_existent = await messages.render_latest()
+            expected_manual_head = "Line 1 (manual)\nLine 2 (manual)"
+            self.assertIn(f"<file_content>{expected_manual_head}</file_content>", rendered_non_existent[0]['content'])
+            self.assertNotIn("from file", rendered_non_existent[0]['content'])
+        finally:
+            if os.path.exists(non_existent_file):
+                os.remove(non_existent_file)
+
+    async def test_auto_convert_image_dict_to_image_provider(self):
+        """测试 UserMessage 是否能自动转换 image_url 字典为 Images provider"""
+        base64_image_data = "/9j/4AAQSkZJRgABAQEAYABgAAD/4QAiRXhpZgAATU0AKgAAAAgAAQESAAMAAAABAAEAAAAAAAD/2wBDAAIBAQIBAQICAgICAgICAwUDAwMDAwYEBAMFBwYHBwcGBwcICQsJCAgKCAcHCg0KCgsMDAwMBwkODw0MDgsMDAz/2wBDAQICAgMDAwYDAwYMCAcIDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAz/wAARCAABAAEDASIAAhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQAAAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWmp6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEAAwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSExBhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElKU1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD9/KKKKAP/2Q=="
+        image_dict = {
+            'type': 'image_url',
+            'image_url': {
+                'url': f'data:image/jpeg;base64,{base64_image_data}'
+            }
+        }
+
+        # This is the functionality we are testing.
+        # The UserMessage should be able to take this dictionary directly.
+        message = UserMessage(image_dict)
+
+        # 1. Verify that the message contains exactly one provider.
+        self.assertEqual(len(message.provider()), 1)
+
+        # 2. Verify that the provider is an instance of the Images class.
+        image_provider = message.provider()[0]
+        self.assertIsInstance(image_provider, Images)
+
+        # 3. Verify that the content of the Images provider is correct.
+        rendered = await message.render_latest()
+        self.assertEqual(rendered['content'][0]['image_url']['url'], image_dict['image_url']['url'])
+
 
 # ==============================================================================
 # 6. 演示
